/**
 * Copyright 2006-8 Simon Andrews
 *
 *    This file is part of FRETSaw.
 *
 *    FRETSaw is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FRETSaw is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with ChIPMonk; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.FretSaw.Display;

import javax.swing.*;

import uk.ac.bbsrc.babraham.FretSaw.FretSawApplication;

import java.awt.*;
import java.awt.event.*;

public class AboutDialog extends JDialog {

    public AboutDialog (FretSawApplication a) {

        setTitle("About FRETSaw...");
        Container cont = getContentPane();
        cont.setLayout(new BorderLayout());
        cont.setBackground(Color.WHITE);
        
        ImageIcon logo = new ImageIcon(ClassLoader.getSystemResource("Resources/bi_logo.png"));
        
        cont.add(new JLabel("",logo,JLabel.CENTER),BorderLayout.WEST);
        JPanel c = new JPanel();
        c.setLayout(new GridBagLayout());
        c.setBackground(Color.WHITE);
        
        GridBagConstraints constraints = new GridBagConstraints();
        constraints.gridx=1;
        constraints.gridy=1;
        constraints.weightx = 1;
        constraints.weighty=1;
        constraints.fill = GridBagConstraints.NONE;
                
        JLabel program = new SmoothJLabel("FRETSaw FRET Image Viewer",JLabel.CENTER);
        program.setFont(new Font("Dialog",Font.BOLD,18));
        program.setForeground(Color.RED);
        c.add(program,constraints);
        
        constraints.gridy++;
        JLabel version = new SmoothJLabel("Version: "+FretSawApplication.VERSION, JLabel.CENTER);
        version.setFont(new Font("Dialog",Font.BOLD,15));
        version.setForeground(Color.BLUE);
        c.add(version,constraints);

        constraints.gridy++;
        JLabel website = new JLabel("www.bioinformatics.bbsrc.ac.uk/projects/", JLabel.CENTER);
        website.setFont(new Font("Dialog",Font.PLAIN,12));
        c.add(website,constraints);
        constraints.gridy++;

        JLabel copyright = new JLabel("\u00a9 Simon Andrews, Babraham Bioinformatics, 2010", JLabel.CENTER);
        copyright.setFont(new Font("Dialog",Font.PLAIN,12));
        c.add(copyright,constraints);
        constraints.gridy++;

        JLabel includes = new JLabel("This program includes code from the ImageJ and BioFormats projects", JLabel.CENTER);
        includes.setFont(new Font("Dialog",Font.PLAIN,10));
        c.add(includes,constraints);
        
        constraints.gridy++;
        constraints.fill = GridBagConstraints.NONE;
        JButton closeButton = new JButton("Close");
        getRootPane().setDefaultButton(closeButton);
        closeButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent arg0) {
                setVisible(false);
                dispose();
            }
        });
        c.add(closeButton,constraints);
        
        cont.add(c,BorderLayout.CENTER);
        
        setSize(550,170);
        setLocationRelativeTo(a);
        setResizable(false);
        setVisible(true);
    }
    
    private class SmoothJLabel extends JLabel {
    	public SmoothJLabel (String text, int position) {
    		super(text,position);
    	}
        public void paintComponent (Graphics g) {
    		((Graphics2D)g).setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
    		super.paintComponent(g);
        }

    }
}
