/**
 * Copyright 2006-8 Simon Andrews
 *
 *    This file is part of FRETSaw.
 *
 *    FRETSaw is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    FRETSaw is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with ChIPMonk; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.FretSaw.Preferences;

import java.io.File;

public class FretSawPreferences {

	private static FretSawPreferences instance = new FretSawPreferences();
	private int minIntensity = 150;
	private boolean useAutoScale = true;
	private boolean addOverlay = true;
	private double minRatio = 1;
	private double maxRatio = 3;
	private int smoothing = 1;
	private int brightness = 100;
	private File lastDirectory;
	
	private FretSawPreferences () {}
	
	
	public static FretSawPreferences getInstance () {
		return instance;
	}
	
	public int minIntensity () {
		return minIntensity;
	}
	
	public void setMinIntensity (int minIntensity) {
		if (minIntensity < 0) throw new IllegalArgumentException("Intensity must be > 0");
		this.minIntensity = minIntensity;
	}
	
	public double minRatio () {
		return minRatio;
	}
	
	public double maxRatio () {
		return maxRatio;
	}
	
	public int brightness () {
		return brightness;
	}
	
	public void setBrightness (int brightness) {
		this.brightness = brightness;
	}
	
	public void setRatioRange (double min, double max) {
		
		if (min < 0 || max < 0) throw new IllegalArgumentException("Ratios must be > 0");
		if (! (max > min)) throw new IllegalArgumentException("Max ratio must be higher than min ratio");
		
		maxRatio = max;
		minRatio = min;
	}
	
	public int smoothing () {
		return smoothing;
	}
	
	public void setSmoothing (int smoothing) {
		if (smoothing < 0 || smoothing > 5) {
			throw new IllegalArgumentException("Smoothing must be in the range 0 - 5");
		}
		this.smoothing = smoothing;
	}
	
	public File lastDirectory () {
		return lastDirectory;
	}
	
	public void setLastDirectory (File file) {
		if (file == null) return;
		
		if (file.isDirectory()) {
			lastDirectory = file;
		}
		else {
			lastDirectory = file.getParentFile();
		}
	}
	
	public void setAddOverlay (boolean add) {
		addOverlay = add;
	}
	
	public boolean addOverlay () {
		return addOverlay;
	}
	
	public boolean useAutoScale () {
		return useAutoScale;
	}
	
	public void setUseAutoScale (boolean useAutoScale) {
		this.useAutoScale = useAutoScale;
	}
	
}
